"""
Configuration module for RedXAuthCodes
Provides centralized configuration management
"""

import os
from typing import Dict, Any

CONFIG: Dict[str, Any] = {
    # Database configuration
    'database_url': os.getenv('DATABASE_URL'),
    'db_host': os.getenv('PGHOST'),
    'db_port': os.getenv('PGPORT'),
    'db_user': os.getenv('PGUSER'),
    'db_password': os.getenv('PGPASSWORD'),
    'db_name': os.getenv('PGDATABASE'),

    # Email configuration
    'email': {
        'sender_email': os.getenv('SENDER_EMAIL'),
        'password': os.getenv('EMAIL_APP_PASSWORD'),
        'smtp_server': 'smtp.gmail.com',
        'smtp_port': 587,
        'use_tls': True
    },

    # Rate limiting defaults
    'rate_limit_window': 3600,  # 1 hour
    'rate_limit_max_requests': 100,

    # Code generation settings
    'default_code_length': 8,
    'default_expiry_minutes': 15,

    # Subscription settings
    'default_trial_days': 7,
    'default_subscription_days': 30,
}