from dataclasses import dataclass
from datetime import datetime
from typing import Optional, Dict

@dataclass
class VerificationCode:
    """Data class for verification code details"""
    email: str
    code: str
    created_at: datetime
    expires_at: datetime
    used: bool = False
    id: Optional[int] = None

    def to_dict(self) -> Dict:
        """Convert to dictionary format"""
        return {
            'email': self.email,
            'code': self.code,
            'created_at': self.created_at.strftime("%m/%d/%Y/%I:%M%p").lower(),
            'expires_at': self.expires_at.strftime("%m/%d/%Y/%I:%M%p").lower(),
            'used': self.used,
            'id': self.id
        }

@dataclass
class Subscription:
    """Data class for subscription details"""
    email: str
    plan_type: str
    start_date: datetime
    end_date: datetime
    active: bool = True
    id: Optional[int] = None

    def to_dict(self) -> Dict:
        """Convert to dictionary format"""
        return {
            'email': self.email,
            'plan_type': self.plan_type,
            'start_date': self.start_date.strftime("%m/%d/%Y/%I:%M%p").lower(),
            'end_date': self.end_date.strftime("%m/%d/%Y/%I:%M%p").lower(),
            'active': self.active,
            'id': self.id
        }